summaryrefslogtreecommitdiff
path: root/render/box.h
diff options
context:
space:
mode:
Diffstat (limited to 'render/box.h')
-rw-r--r--render/box.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/render/box.h b/render/box.h
index 1f35adad9..4ac3453aa 100644
--- a/render/box.h
+++ b/render/box.h
@@ -132,7 +132,8 @@ typedef enum {
NEED_MIN = 1 << 8, /* minimum width is required for layout */
REPLACE_DIM = 1 << 9, /* replaced element has given dimensions */
IFRAME = 1 << 10, /* box contains an iframe */
- CONVERT_CHILDREN = 1 << 11 /* wanted children converting */
+ CONVERT_CHILDREN = 1 << 11, /* wanted children converting */
+ IS_REPLACED = 1 << 12 /* box is a replaced element */
} box_flags;
/* Sides of a box */